.. Pulsar documentation master file, created by
   sphinx-quickstart on Sun Dec 16 23:16:23 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to Pulsar's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   install
   configure
   job_managers
   containers
   galaxy_conf
   scripts
   conduct
   contributing
   organization
   developing
   history

Indices and tables
==================


* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

